@@ -48,10 +48,23 @@ from .models.vendor_workflow import (
     VendorWorkflowInstallResponse,
     VendorWorkflowUninstallResponse,
 )
+from .models.vendor_knowledgebase import (
+    VendorKnowledgeBaseSetting,
+    VendorKnowledgeBaseSettingsResponse,
+    VendorKnowledgeBase,
+    VendorKnowledgeBaseStatus,
+    VendorKnowledgeBasesResponse,
+    VendorKnowledgeBaseDetail,
+    VendorKnowledgeBaseInstallRequest,
+    VendorKnowledgeBaseInstallSummary,
+    VendorKnowledgeBaseInstallResponse,
+    VendorKnowledgeBaseUninstallResponse,
+)
 from .services.vendor_assistant import VendorAssistantService
 from .services.vendor_workflow import VendorWorkflowService
+from .services.vendor_knowledgebase import VendorKnowledgeBaseService
 
-__version__ = "0.2.10"
+__version__ = "0.2.11"
 __all__ = [
     "CodeMieClient",
     "VendorType",
@@ -82,4 +95,15 @@ __all__ = [
     "VendorWorkflowInstallResponse",
     "VendorWorkflowUninstallResponse",
     "VendorWorkflowService",
+    "VendorKnowledgeBaseSetting",
+    "VendorKnowledgeBaseSettingsResponse",
+    "VendorKnowledgeBase",
+    "VendorKnowledgeBaseStatus",
+    "VendorKnowledgeBasesResponse",
+    "VendorKnowledgeBaseDetail",
+    "VendorKnowledgeBaseInstallRequest",
+    "VendorKnowledgeBaseInstallSummary",
+    "VendorKnowledgeBaseInstallResponse",
+    "VendorKnowledgeBaseUninstallResponse",
+    "VendorKnowledgeBaseService",
 ]
