@@ -15,6 +15,7 @@ from ..services.files import FileOperationService
 from ..services.webhook import WebhookService
 from ..services.vendor_assistant import VendorAssistantService
 from ..services.vendor_workflow import VendorWorkflowService
+from ..services.vendor_knowledgebase import VendorKnowledgeBaseService
 
 
 class CodeMieClient:
@@ -97,6 +98,9 @@ class CodeMieClient:
         self.vendor_workflows = VendorWorkflowService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendor_knowledgebases = VendorKnowledgeBaseService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
 
     @property
     def token(self) -> str:
@@ -149,4 +153,7 @@ class CodeMieClient:
         self.vendor_workflows = VendorWorkflowService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.vendor_knowledgebases = VendorKnowledgeBaseService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
         return self._token
