@@ -1,6 +1,6 @@
 """Workflow execution payload models."""
 
-from typing import Optional
+from typing import Optional, Union
 from pydantic import BaseModel, ConfigDict, Field
 
 
@@ -9,7 +9,7 @@ class WorkflowExecutionCreateRequest(BaseModel):
 
     model_config = ConfigDict(populate_by_name=True)
 
-    user_input: Optional[str] = Field(
+    user_input: Optional[Union[str, dict, list, int, float, bool]] = Field(
         None, description="User input for the workflow execution"
     )
     file_name: Optional[str] = Field(
